'********************************************************************
' Author: Paul Heasley
' Website: www.phdesign.com.au
' Copyright (C) 2006 Paul Heasley 
' Date: 10 October 2006
' Purpose: Allows a multi-line search and replace box in PSPad Editor.
'
'********************************************************************

Const module_name  = "phReplace"
Const module_ver   = "1.4.2"

Sub phReplace 
  '**************************************************
  'Purpose: Runs the phReplace add-on which allows 
  '         for a multiline search and replace. The 
  '         add-on is stored as a dll library, 
  '         most of this script is just trying to 
  '         register or update the library if needed.
  '**************************************************
  Dim objEditor
  Dim objReplace
  Dim strLibraryPath
  Dim i
  Dim intUpFolders
  
  On Error Resume Next
  If editorsCount = 0 Then Exit Sub
  
  'Finds the location of phreplace.dll. intUpFolders sets how many folders up from  
  ' the scripts folder the PSPad root folder is located. For me it's up 2 folders 
  ' (e.g. \PSPad\Script\VBScript\). But feel free to change this if it's different for you.
  intUpFolders = 2
  strLibraryPath = modulePath 
  For i = 1 To intUpFolders 
    strLibraryPath = Left(strLibraryPath, InStrRev(strLibraryPath, "\", Len(strLibraryPath) - 1))
  Next
  strLibraryPath = strLibraryPath & "phreplace.dll"
  
  If Not LibIsRegistered Then   'If dll isn't registered or isn't latest version
    If Not RegisterDLL(strLibraryPath, True) Then   'Try to re-register the library.
      CustomError 1, strLibraryPath
    End If
  End If
  Err.Clear
  Set objReplace = CreateObject("phReplace.clsReplace")
  If Err.Number <> 0 Then
    CustomError 2, ""
    Exit Sub
  End If
  Set objEditor = NewEditor()
  objEditor.assignActiveEditor
  
  Err.Clear
  'Run phReplace
  objReplace.StartApplication objEditor
  If Err.Number <> 0 Then
    CustomError 3, ""
    Exit Sub
  End If
  
  'Distroy old objects
  Set objReplace = Nothing
  Set objEditor = Nothing
End Sub

Function RegisterDLL(strFilename, blnInstall) 
  '**************************************************
  'Purpose: Installs or uninstalls dll's temporarily.
  'Inputs:  strFilename: The name of the dll file.
  '         blnInstall: If false then it unregisters
  '         the dll.
  'Returns: True if install succeeds otherwise false.
  '**************************************************
  Dim WsShell
  Dim fso
  Dim strCommand
  
	Set WshShell = CreateObject("Wscript.Shell")
	Set fso = CreateObject("Scripting.FileSystemObject")
	
	strCommand = "regsvr32 /s "
	If Not blnInstall Then
	 strCommand = strCommand & "/u "
	End If
	RegisterDLL = False
  If fso.FileExists(strFilename) Then
    WshShell.Run strCommand & """" & strFilename & """", 1, True
    RegisterDLL = True
  End If
End Function

Function LibIsRegistered
  '**************************************************
  'Purpose: Checks that the dll is registered by trying
  '         to create the phReplace object. Also checks
  '         that the dll version is the same as this 
  '         script, if this method fails then it should
  '         try to reload the dll.
  '**************************************************
  Dim objApp
  
  On Error Resume Next
  LibIsRegistered = True
  Set objApp = CreateObject("phReplace.clsReplace")
  If Err.Number <> 0 Then
    LibIsRegistered = False
  ElseIf objApp.AppVersion <> module_ver Then
    LibIsRegistered = False
  End If
End Function

Sub CustomError(intErr, strErrMessage)
  Select Case intErr
  Case 1: 
    strErrMessage = "Error " & intErr & ": " & "Unable to register library " & strErrMessage
  
  Case 2:
    strErrMessage = "Error " & intErr & ": " & "Unable to start phReplace add-on"
  
  Case 3: 
    strErrMessage = "Error " & intErr & ": " & "There was an error running the phReplace add-on"
  
  Case Else:
    If Len(strErrMessage) = 0 Then
      strErrMessage = "Unspecified Runtime Error"
    End If
   
  End Select
  strErrMessage = strErrMessage & vbNewLine & vbNewLine & "Please check the phreplace.txt file or www.phdesign.com.au for help"
  
  MsgBox strErrMessage, 0, "Search / Replace by phdesign.com.au"
  'Err.Raise intErr, "Search / Replace by phdesign.com.au", strErrMessage, "phreplace.txt"
End Sub

Sub Init
  addMenuItem "Multiline Search / Replace", "", "phReplace", "Ctrl+Alt+F"
End Sub
